$VAR1 = [

    {   'User' => [
            [ 'user_id',	'first_name',	'last_name',	'permission_type_id',	'department_type_id',],
            [ 1,			'John',			'Doe' ,				1,						1					 ],
            [ 2,			'Flash',		'Gordon' ,			3,						2					 ],
            [ 3,			'Vanessa',		'Paradis',			1,						3					 ]
        ],
    },
 
];