$VAR1 = [

	{   'PermissionType' => [
            [ 'permission_type_id',	'name'			],
            [ 1,					'Administrator'	],
            [ 2,					'Leader'		],
            [ 3,					'User'			]
        ],
    },

];