$VAR1 = [

	{   'StudyType' => [
            [ 'study_type_id',	'name', 		'user_id'	],
            [ 1,			'clinical'		, 1				],
            [ 2,			'preclinical'	, 1				],
            [ 3,			'postclinical'	, 2				]
        ],
    },

];