$VAR1 = [

    {   'User' => [
            [ 'first_name',	'last_name',	'permission_type_id',],
            [ 'John',		'Doe' ,			1,					 ],
            [ 'Flash',		'Gordon' ,		3,					 ],
            [ 'Vanessa',	'Paradis',		1,					 ]
        ],
    },


 
];